@@ -1,7 +1,7 @@
 # Test::DistManifest
 #  Tests that your manifest matches the distribution as it exists.
 #
-# $Id: DistManifest.pm 8673 2009-08-20 03:41:42Z FREQUENCY@cpan.org $
+# $Id: DistManifest.pm 9529 2009-10-04 04:34:32Z FREQUENCY@cpan.org $
 
 package Test::DistManifest;
 
@@ -15,11 +15,11 @@ Test::DistManifest - Author test that validates a package MANIFEST
 
 =head1 VERSION
 
-Version 1.003 ($Id: DistManifest.pm 8673 2009-08-20 03:41:42Z FREQUENCY@cpan.org $)
+Version 1.004 ($Id: DistManifest.pm 9529 2009-10-04 04:34:32Z FREQUENCY@cpan.org $)
 
 =cut
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 $VERSION = eval $VERSION;
 
 =head1 EXPORTS
@@ -357,7 +357,7 @@ Example code:
 
 =head1 AUTHOR
 
-Jonathan Yu E<lt>frequency@cpan.orgE<gt>
+Jonathan Yu E<lt>jawnsy@cpan.orgE<gt>
 
 =head2 CONTRIBUTORS
 
@@ -472,7 +472,7 @@ the module; the emphasis should be on generating helpful error messages.
 
 =head1 LICENSE
 
-Copyright (C) 2008-2009 by Jonathan Yu <frequency@cpan.org>
+Copyright (C) 2008-2009 by Jonathan Yu <jawnsy@cpan.org>
 
 This package is distributed under the same terms as Perl itself. Please
 see the F<LICENSE> file included in this distribution for full details of
